"use strict";
var glob = require('glob');
var request = require('request');
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var assert_1 = tslib_1.__importDefault(require("assert"));
exports.defaults = {
    keepLocalFiles: false,
    keepSourcemaps: false,
    backupHTMLFiles: false,
    manifestFilename: false,
    token: '',
    bucket: '',
    is_remain_filename: true,
    is_use_cdn: true,
    is_use_https: true,
    env: 'test',
    interface_ip: '',
    assets_domain_name: '',
    is_debug: false,
    folder: ''
};
/** merge user configuration with defaults */
exports.standardize = function (config) {
    assert_1.default(typeof config.token === 'string' && config.token, '`config.token` is invalid.');
    assert_1.default(typeof config.bucket === 'string' && config.bucket, '`config.bucket` is invalid.');
    return tslib_1.__assign({}, exports.defaults, config);
};
function getInterfaceIp(env) {
    switch (env) {
        case 'test':
            return 'http://cdn-service.test.stary.ltd';
        case 'test-oversea':
            return 'https://cdn-service.k8s.stary.ltd';
        case 'prod':
            return 'https://cdn-service.system.stary.ltd';
        default:
            return 'https://cdn-service.system.stary.ltd';
    }
}
var requestFacade = {
    send: function (url, reqData, config) {
        return new Promise(function (resolve, reject) {
            var req = {
                url: (config.interface_ip || getInterfaceIp(config.env || 'test')) + url,
                formData: reqData,
                headers: {}
            };
            if (config.env === 'prod') {
                req.headers = {
                    Host: 'cdn-service-internal.stary.ltd'
                };
            }
            request.post(req, function (error, _response, body) {
                var res = null;
                try {
                    res = JSON.parse(body);
                }
                catch (err) {
                    reject(err);
                    return;
                }
                if (error) {
                    reject(error);
                }
                if (config.is_debug) {
                    console.log('---response: ', res);
                }
                resolve(res.data);
            });
        });
    }
};
exports.uploadContent = function (fileContent, file, config) {
    var pos = file.lastIndexOf('/');
    var fileName = file.substr(pos + 1);
    var form = {
        token: config.token,
        bucket: config.bucket,
        is_remain_filename: config.is_remain_filename ? 'true' : 'false',
        is_use_cdn: config.is_use_cdn ? 'true' : 'false',
        is_use_https: config.is_use_https ? 'true' : 'false',
        file: {
            value: Buffer.from(fileContent),
            options: {
                filename: fileName
            }
        },
        folder: config.folder
    };
    return requestFacade
        .send('/api/resource/upload', form, config)
        .then(function (res) {
        // @ts-ignore
        var result = res.success_result.concat(res.fail_result);
        var url = result[0].cdn_url || result[0].url || '上传失败';
        if (config.assets_domain_name) {
            url = url.replace(/^https?:\/\/[^/]+/, config.assets_domain_name);
        }
        return url;
    })
        .catch(function (err) {
        console.log('上传出错: ', err);
        throw new Error(err);
    });
};
